Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(279)

Unified Diff: webrtc/p2p/base/p2ptransportchannel.cc

Issue 1868353004: Update prflx candidates' generation when setting ICE credentials. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Only need to pass in the last ICE params and the generation. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/candidate.h ('k') | webrtc/p2p/base/p2ptransportchannel_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/p2ptransportchannel.cc
diff --git a/webrtc/p2p/base/p2ptransportchannel.cc b/webrtc/p2p/base/p2ptransportchannel.cc
index 66532411b29f5241c6b0f163d87c91d7ba9cbe2a..acbcfd77e7165281e43588b4f7ce21dc2bf1f025 100644
--- a/webrtc/p2p/base/p2ptransportchannel.cc
+++ b/webrtc/p2p/base/p2ptransportchannel.cc
@@ -390,10 +390,15 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag,
candidate.set_password(ice_pwd);
}
}
// We need to update the credentials for any peer reflexive candidates.
for (Connection* conn : connections_) {
- conn->MaybeSetRemoteIceCredentials(ice_ufrag, ice_pwd);
+ conn->MaybeSetRemoteIceCredentialsAndGeneration(
+ ice_ufrag, ice_pwd,
+ static_cast<int>(remote_ice_parameters_.size() - 1));
}
+ // Updating the remote ICE candidate generation could change the sort order.
+ RequestSort();
}
void P2PTransportChannel::SetRemoteIceMode(IceMode mode) {
« no previous file with comments | « webrtc/p2p/base/candidate.h ('k') | webrtc/p2p/base/p2ptransportchannel_unittest.cc » ('j') | no next file with comments »
@@ -390,10 +390,15 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag,
}
}
- // We need to update the credentials for any peer reflexive candidates.
+ // We need to update the credentials and generation for any peer reflexive
+ // candidates.
for (Connection* conn : connections_) {

Powered by Google App Engine
This is Rietveld 408576698